# ------------------------------ Beginning of function -----------------------------------------------
##########
### Function to draw confidence ellipses on any MFA result object obtained via the MFA function in FactoMineR.
### To save the function to your hard drive, copy all these lines of text and save it in a text file with the name     conf.R     (and not conf.txt).
### Load this function in R by writing     source(file.choose())     in R command promt and choose this file (named 'conf.R').
### Run this function in R by writing     MFAconf(X)     in R command promt where X defines your MFA result object.
### The function gives you the option of plotting specific model axes.
##########

# MFA result object and axes to draw inside the function
MFAconf=function(MFAresob, axes = c(1, 2)){

if (!require("FactoMineR")) install.packages("FactoMineR"); library("FactoMineR")

# The number of samples (n)
n=dim(MFAresob$ind$coord)[1]

# The number of groups of variables (m)
m=dim(MFAresob$group$coord)[1]

# Creating a new data frame with one row for each sample's assiociated MFA group of variables.
CATnames <- vector(mode="character", length=n*m)
for (j in 1:n){CATnames[(((j-1)*m)+1):(j*m)] <- dimnames(MFAresob$ind$coord[order(row.names(MFAresob$ind$coord)),])[[1]][j]}
PartielDim <- cbind.data.frame(names=CATnames,MFAresob$ind$coord.partiel)

# Bootstrapping the new data frame
Boot <- simule(PartielDim, nb.simul=500)

# Creating ellipses around 95% of the bootstrapped means
EllipCoord <- coord.ellipse(Boot$simul, level.conf=0.95, bary=FALSE, axes=axes)

# Plotting the ellipses
plot.MFA(MFAresob, title ='', axes = axes, choix = "ind", ellipse = EllipCoord, ellipse.par = NULL)
}
# ------------------------------ End of function -----------------------------------------------------
